@@ -1,6 +1,4 @@
-"""
-Module for training BDTs
-"""
+"""Module for training BDTs."""
 
 # stdlib
 import json
@@ -21,7 +19,7 @@ import pandas as pd
 import pygram11
 from scipy import interp
 from sklearn.model_selection import KFold, train_test_split
-from sklearn.metrics import auc, roc_auc_score, roc_curve
+from sklearn.metrics import auc, roc_auc_score, roc_curve, plot_roc_curve
 
 # fmt: off
 try:
@@ -39,11 +37,11 @@ except ImportError:
 # tdub
 from tdub.art import setup_style
 from tdub.frames import iterative_selection, drop_cols
+from tdub.math import ks_twosample_binned
+from tdub.hist import bin_centers
 from tdub.utils import (
     Region,
-    bin_centers,
     quick_files,
-    ks_twosample_binned,
     get_selection,
     get_features,
 )
@@ -67,51 +65,48 @@ def prepare_from_root(
     use_tptrw: bool = False,
     test_case_size: Optional[int] = None,
 ) -> Tuple[pd.DataFrame, np.ndarray, np.ndarray]:
-    """Prepare the data for training in a region with signal and background ROOT files
+    r"""Prepare the data to train in a region with signal and background ROOT files.
 
     Parameters
     ----------
     sig_files : list(str)
-       list of signal ROOT files
+        list of signal ROOT files
     bkg_files : list(str)
-       list of background ROOT files
+        list of background ROOT files
     region : Region or str
-       the region where we're going to perform the training
+        the region where we're going to perform the training
     branches : list(str), optional
-       if not None, we override the list of features defined by the region
+        if not None, we override the list of features defined by the region
     override_selection : str, optional
-       a manual selection string to apply to the dataset (this will override
-       the region defined selection).
+        a manual selection string to apply to the dataset (this will override
+        the region defined selection).
     weight_mean : float, optional
-       scale all weights such that the mean weight is this
-       value. Cannot be used with ``weight_scale``.
+        scale all weights such that the mean weight is this value. Cannot be
+        used with `weight_scale`.
     weight_scale : float, optional
-       value to scale all weights by, cannot be used with
-       ``weight_mean``.
+        value to scale all weights by, cannot be used with `weight_mean`.
     scale_sum_weights : bool
-       scale sum of weights of signal to be sum of weights of
-       background
+        scale sum of weights of signal to be sum of weights of background
     use_campaign_weight : bool
-       see the parameter description for
-       :py:func:`tdub.frames.iterative_selection`
+        see the parameter description for
+        :py:func:`tdub.frames.iterative_selection`
     use_tptrw : bool
-       apply the top pt reweighing factor.
+        apply the top pt reweighing factor.
     test_case_size : int, optional
-       if defined, prepare a small "test case" dataset using this many
-       background and training samples
+        if defined, prepare a small test case dataset using this many background
+        and training samples
 
     Returns
     -------
     df : :obj:`pandas.DataFrame`
        the feature matrix
     labels : :obj:`numpy.ndarray`
-       the event labels (``0`` for background; ``1`` for signal)
+       the event labels (0 for background; 1 for signal)
     weights : :obj:`numpy.ndarray`
        the event weights
 
     Examples
     --------
-
     >>> from tdub.utils import quick_files
     >>> from tdub.train import prepare_from_root
     >>> qfiles = quick_files("/path/to/data")
@@ -202,7 +197,7 @@ def prepare_from_root(
 
 
 class SingleTrainingResult:
-    """Describes the properties of a single training
+    """Describes the properties of a single training.
 
     Parameters
     ----------
@@ -243,6 +238,7 @@ class SingleTrainingResult:
         ks_pvalue_bkg: float = -1.0,
         **kwargs,
     ) -> None:
+        """Class init."""
         self.auc = auc
         self.ks_test_sig = ks_test_sig
         self.ks_pvalue_sig = ks_pvalue_sig
@@ -251,6 +247,7 @@ class SingleTrainingResult:
         self.bad_ks = self.ks_pvalue_sig < 0.2 or self.ks_pvalue_bkg < 0.2
 
     def __repr__(self) -> str:
+        """Clean representation of the result."""
         p1 = f"auc={self.auc:0.3}"
         p2 = f"ks_test_sig={self.ks_test_sig:0.5}"
         p3 = f"ks_pvalue_sig={self.ks_pvalue_sig:0.5}"
@@ -271,7 +268,7 @@ def single_training(
     extra_summary_entries: Optional[Dict[str, Any]] = None,
     use_xgboost: bool = False,
 ) -> SingleTrainingResult:
-    """Execute a single training with some parameters
+    """Execute a single training with some parameters.
 
     Parameters
     ----------
@@ -300,7 +297,6 @@ def single_training(
 
     Examples
     --------
-
     >>> from tdub.utils import quick_files
     >>> from tdub.train import prepare_from_root, single_round
     >>> qfiles = quick_files("/path/to/data")
@@ -327,6 +323,7 @@ def single_training(
         df, labels, weights, test_size=test_size, random_state=random_state, shuffle=True
     )
 
+    log.info(f"test size used: {test_size}")
     log.info("selection used on the datasets:")
     log.info("  '%s'" % df.selection_used)
     log.info("features training with:")
@@ -362,6 +359,8 @@ def single_training(
             eval_sample_weight=[validation_w],
         )
 
+    joblib.dump(model, f"model.joblib.gz", compress=("gzip", 3))
+
     fig_proba, ax_proba = plt.subplots()
     fig_pred, ax_pred = plt.subplots()
     fig_roc, ax_roc = plt.subplots()
@@ -439,8 +438,7 @@ def _inspect_single_training(
     nbins_pred: int = 30,
     is_xgb_model: bool = False,
 ) -> SingleTrainingResult:
-    """inspect a single training round and make some plots"""
-
+    """Inspect a single training round and make some plots."""
     # fmt: off
     # get the selection arrays
     test_is_sig = y_test == 1
@@ -527,12 +525,14 @@ def _inspect_single_training(
     ax_pred.set_xlabel("Classifier Response")
 
     # plot the auc
-    fpr, tpr, thresholds = roc_curve(y_test, test_proba, sample_weight=w_test)
-    roc_auc = auc(fpr, tpr)
-    ax_roc.plot(fpr, tpr, lw=1, label=f"AUC = {roc_auc:0.3}")
+    # use the new sklearn plot_roc_curve API
+    rcd = plot_roc_curve(model, X_test, y_test, sample_weight=w_test, ax=ax_roc, lw=2)
+    # fpr, tpr, thresholds = roc_curve(y_test, test_proba, sample_weight=w_test)
+    # roc_auc = auc(fpr, tpr)
+    # ax_roc.plot(fpr, tpr, lw=1, label=f"AUC = {roc_auc:0.3}")
     ax_roc.set_ylabel("True postive rate")
     ax_roc.set_xlabel("False positive rate")
-    ax_roc.grid(color="black", alpha=0.15)
+    ax_roc.grid(color="black", alpha=0.125)
     ax_roc.legend(loc="lower right")
     # fmt: on
 
@@ -544,7 +544,7 @@ def _inspect_single_training(
     )
 
     return SingleTrainingResult(
-        auc=float(roc_auc),
+        auc=float(rcd.roc_auc),
         ks_test_sig=float(ks_stat_sig),
         ks_pvalue_sig=float(ks_p_sig),
         ks_test_bkg=float(ks_stat_bkg),
@@ -562,7 +562,7 @@ def folded_training(
     region: str,
     kfold_kw: Dict[str, Any] = None,
 ) -> float:
-    """Execute a folded training
+    """Execute a folded training.
 
     Train a :obj:`lightgbm.LGBMClassifier` model using :math:`k`-fold
     cross validation using the given input data and parameters.  The
@@ -602,7 +602,6 @@ def folded_training(
 
     Examples
     --------
-
     >>> from tdub.utils import quick_files
     >>> from tdub.train import prepare_from_root
     >>> from tdub.train import folded_training
@@ -858,7 +857,7 @@ def gp_minimize_auc(
     esr: Optional[int] = 10,
     random_state: int = 414,
 ):
-    """Minimize AUC using Gaussian processes
+    """Minimize AUC using Gaussian processes.
 
     This is our hyperparameter optimization procedure which uses the
     :py:func:`skopt.gp_minimize` functions from Scikit-Optimize.
@@ -882,7 +881,6 @@ def gp_minimize_auc(
 
     Examples
     --------
-
     >>> from tdub.utils import Region
     >>> from tdub.train import prepare_from_root, gp_minimize_auc
     >>> gp_minimize_auc("/path/to/data", Region.r2j1b, "DS", "opt_DS_2j1b")
