@@ -5,22 +5,16 @@ Module for general utilities
 # stdlib
 import copy
 import logging
-import numbers
-import math
 import os
 import re
 from dataclasses import dataclass
 from enum import Enum
 from glob import glob
 from pathlib import PosixPath
-
-from typing import Union, Iterable, Optional, Dict, List, Tuple, Set
+from typing import Union, Iterable, Optional, Dict, List, Set
 
 # external
-import numpy as np
-import scipy.special
 import uproot
-import pandas as pd
 import formulate
 
 # tdub
@@ -48,7 +42,6 @@ class Region(Enum):
 
     Examples
     --------
-
     Using this enum for grabing the ``2j2b`` region from a set of
     files:
 
@@ -61,6 +54,7 @@ class Region(Enum):
     r1j1b = 0
     r2j1b = 1
     r2j2b = 2
+    rUnkn = 9
 
     @staticmethod
     def from_str(s: str) -> "Region":
@@ -86,7 +80,6 @@ class Region(Enum):
 
         Examples
         --------
-
         >>> from tdub.utils import Region
         >>> Region.from_str("1j1b")
         <Region.r1j1b: 0>
@@ -215,7 +208,6 @@ def categorize_branches(
 
     Examples
     --------
-
     >>> from tdub.utils import categorize_branches
     >>> branches = ["pT_lep1", "pT_lep2", "weight_nominal", "weight_sys_jvt", "reg2j2b"]
     >>> cated = categorize_branches(branches)
@@ -277,18 +269,23 @@ def quick_files(datapath: FileLike, campaign: Optional[str] = None) -> Dict[str,
     The lists of files are sorted alphabetically. These types of
     samples are currently tested:
 
-    - ``ttbar`` (410472 full sim)
-    - ``ttbar_AFII`` (410472 fast sim)
-    - ``ttbar_PS`` (410558 fast sim)
-    - ``ttbar_hdamp`` (410482 fast sim)
-    - ``tW_DR`` (410648, 410649 full sim)
-    - ``tW_DR_AFII`` (410648, 410648 fast sim)
-    - ``tW_DR_PS`` (411038, 411039 fast sim)
-    - ``tW_DS`` (410656, 410657 full sim)
-    - ``Diboson``
-    - ``Zjets``
-    - ``MCNP``
-    - ``Data``
+    - `ttbar` (410472 full sim)
+    - `ttbar_AFII` (410472 fast sim)
+    - `ttbar_PS` (410558 fast sim)
+    - `ttbar_hdamp` (410482 fast sim)
+    - `ttbar_inc` (410470 full sim)
+    - `ttbar_inc_AFII` (410470 fast sim)
+    - `tW_DR` (410648, 410649 full sim)
+    - `tW_DR_AFII` (410648, 410648 fast sim)
+    - `tW_DR_PS` (411038, 411039 fast sim)
+    - `tW_DR_inc` (410646, 410647 full sim)
+    - `tW_DR_inc_AFII` (410646, 410647 fast sim)
+    - `tW_DS` (410656, 410657 full sim)
+    - `tW_DS_inc` (410654, 410655 ful sim)
+    - `Diboson`
+    - `Zjets`
+    - `MCNP`
+    - `Data`
 
     Parameters
     ----------
@@ -327,18 +324,48 @@ def quick_files(datapath: FileLike, campaign: Optional[str] = None) -> Dict[str,
         if campaign not in ("MC16a", "MC16d", "MC16e"):
             raise ValueError(f"{campaign} but be either 'MC16a', 'MC16d', or 'MC16e'")
         camp = f"_{campaign}"
+
     path = str(PosixPath(datapath).resolve())
+
+    # ttbar
     ttbar_files = sorted(glob(f"{path}/ttbar_410472_FS{camp}*nominal.root"))
     ttbar_AFII_files = sorted(glob(f"{path}/ttbar_410472_AFII{camp}*nominal.root"))
     ttbar_PS_files = sorted(glob(f"{path}/ttbar_410558*AFII{camp}*nominal.root"))
     ttbar_hdamp_files = sorted(glob(f"{path}/ttbar_410482_AFII{camp}*nominal.root"))
-    tW_DR_AFII_files = sorted(glob(f"{path}/tW_DR_41064*AFII{camp}*nominal.root"))
+    ttbar_inc_files = sorted(glob(f"{path}/ttbar_410470_FS{camp}*nominal.root"))
+    ttbar_inc_AFII_files = sorted(glob(f"{path}/ttbar_410470_AFII{camp}*nominal.root"))
+
+    # tW
     tW_DR_files = sorted(
         glob(f"{path}/tW_DR_410648_FS{camp}*nominal.root")
         + glob(f"{path}/tW_DR_410649_FS{camp}*nominal.root")
     )
-    tW_DR_PS_files = sorted(glob(f"{path}/tW_DR_41103*AFII{camp}*nominal.root"))
-    tW_DS_files = sorted(glob(f"{path}/tW_DS_41065*FS{camp}*nominal.root"))
+    tW_DR_AFII_files = sorted(
+        glob(f"{path}/tW_DR_410648_AFII{camp}*nominal.root")
+        + glob(f"{path}/tW_DR_410649_AFII{camp}*nominal.root")
+    )
+    tW_DR_inc_files = sorted(
+        glob(f"{path}/tW_DR_410646_FS{camp}*nominal.root")
+        + glob(f"{path}/tW_DR_410647_FS{camp}*nominal.root")
+    )
+    tW_DR_inc_AFII_files = sorted(
+        glob(f"{path}/tW_DR_410646_AFII{camp}*nominal.root")
+        + glob(f"{path}/tW_DR_410647_AFII{camp}*nominal.root")
+    )
+    tW_DR_PS_files = sorted(
+        glob(f"{path}/tW_DR_411038_AFII{camp}*nominal.root")
+        + glob(f"{path}/tW_DR_411039_AFII{camp}*nominal.root")
+    )
+    tW_DS_files = sorted(
+        glob(f"{path}/tW_DS_410656_FS{camp}*nominal.root")
+        + glob(f"{path}/tW_DS_410657_FS{camp}*nominal.root")
+    )
+    tW_DS_inc_files = sorted(
+        glob(f"{path}/tW_DS_410654_FS{camp}*nominal.root")
+        + glob(f"{path}/tW_DS_410655_FS{camp}*nominal.root")
+    )
+
+    # Minor backgrounds
     Diboson_files = sorted(glob(f"{path}/Diboson_*FS{camp}*nominal.root"))
     Zjets_files = sorted(glob(f"{path}/Zjets_*FS{camp}*nominal.root"))
     MCNP_files = sorted(glob(f"{path}/MCNP_*FS{camp}*nominal.root"))
@@ -359,10 +386,15 @@ def quick_files(datapath: FileLike, campaign: Optional[str] = None) -> Dict[str,
         "ttbar_AFII": ttbar_AFII_files,
         "ttbar_PS": ttbar_PS_files,
         "ttbar_hdamp": ttbar_hdamp_files,
+        "ttbar_inc": ttbar_inc_files,
+        "ttbar_inc_AFII": ttbar_inc_AFII_files,
         "tW_DR": tW_DR_files,
         "tW_DR_AFII": tW_DR_AFII_files,
         "tW_DR_PS": tW_DR_PS_files,
+        "tW_DR_inc": tW_DR_inc_files,
+        "tW_DR_inc_AFII": tW_DR_inc_AFII_files,
         "tW_DS": tW_DS_files,
+        "tW_DS_inc": tW_DS_inc_files,
         "Diboson": Diboson_files,
         "Zjets": Zjets_files,
         "MCNP": MCNP_files,
@@ -384,9 +416,9 @@ def files_for_tree(
     datapath : str or os.PathLike
        path where all of the ROOT files live
     sample_prefix : str
-       the prefix for the sample we want (``"ttbar"`` or ``"tW_DR"`` or ``"tW_DS"``)
+       the prefix for the sample we want (`"ttbar"` or `"tW_DR"` or `"tW_DS"`)
     tree_name : str
-       the name of the ATLAS systematic tree (e.g. ``"nominal"`` or ``"EG_RESOLUTION_ALL__1up"``)
+       the name of the ATLAS systematic tree (e.g. `"nominal"` or `"EG_RESOLUTION_ALL__1up"`)
     campaign : str, optional
        enforce a single campaign ("MC16a", "MC16d", or "MC16e")
 
@@ -397,7 +429,6 @@ def files_for_tree(
 
     Examples
     --------
-
     >>> from tdub.utils import files_for_tree
     >>> files_for_tree("/data/path", "ttbar", "JET_CategoryReduction_JET_JER_EffectiveNP_4__1up")
     ['/data/path/ttbar_410472_FS_MC16a_JET_CategoryReduction_JET_JER_EffectiveNP_4__1up.root',
@@ -425,79 +456,6 @@ def files_for_tree(
         )
 
 
-def bin_centers(bin_edges: np.ndarray) -> np.ndarray:
-    """Get bin centers given bin edges
-
-    Parameters
-    ----------
-    bin_edges : numpy.ndarray
-       edges defining binning
-
-    Returns
-    -------
-    numpy.ndarray
-       the centers associated with the edges
-
-    Examples
-    --------
-
-    >>> import numpy as np
-    >>> from tdub.utils import bin_centers
-    >>> bin_edges = np.linspace(25, 225, 11)
-    >>> centers = bin_centers(bin_edges)
-    >>> bin_edges
-    array([ 25.,  45.,  65.,  85., 105., 125., 145., 165., 185., 205., 225.])
-    >>> centers
-    array([ 35.,  55.,  75.,  95., 115., 135., 155., 175., 195., 215.])
-
-    """
-    return (bin_edges[1:] + bin_edges[:-1]) * 0.5
-
-
-def edges_and_centers(
-    bins: Union[int, Iterable], range: Optional[Tuple[float, float]] = None
-) -> np.array:
-    """Create arrays for edges and bin centers
-
-    Parameters
-    ----------
-    bins : int or sequence of scalers
-       the number of bins or sequence representing bin edges
-    range : tuple(float, float), optional
-       the minimum and maximum defining the bin range (used if bins is integral)
-
-    Returns
-    -------
-    :py:obj:`numpy.ndarray`
-       the bin edges
-    :py:obj:`numpy.ndarray`
-       the bin centers
-
-    Examples
-    --------
-
-    from bin multiplicity and a range
-
-    >>> from tdub.utils import edges_and_centers
-    >>> edges, centers = edges_and_centers(bins=20, range=(25, 225))
-
-    from pre-existing edges
-
-    >>> edges, centers = edges_and_centers(np.linspace(0, 10, 21))
-
-    """
-    if isinstance(bins, numbers.Integral):
-        if range is None:
-            raise ValueError("for integral bins we require non-None range")
-        edges = np.linspace(range[0], range[1], bins + 1)
-    else:
-        edges = np.asarray(bins)
-        if not np.all(edges[1:] >= edges[:-1]):
-            raise ValueError("bins edges must monotonically increase")
-    centers = bin_centers(edges)
-    return edges, centers
-
-
 def get_branches(
     file_name: FileOrFiles,
     tree: str = "WtLoop_nominal",
@@ -524,7 +482,6 @@ def get_branches(
 
     Examples
     --------
-
     A file with two kinematic variables and two weights
 
     >>> from tdub.utils import get_branches
@@ -551,56 +508,6 @@ def get_branches(
     return list(set(bs) ^ weights)
 
 
-def conservative_branches(
-    file_name: FileOrFiles, tree: str = "WtLoop_nominal"
-) -> List[str]:
-    """Get branches in a ROOT file that form a conservative minimum
-
-    we define "conservative minimum" as the branches necessary for
-    using our BDT infrastructure, so this conservative minimum
-    includes all of the features used by the BDTs as well as the
-    variables necessary for region selection.
-
-    Parameters
-    ----------
-    file_name : str or os.PathLike or list(str) or list(os.PathLike)
-       the ROOT file name
-    tree : str
-       the ROOT tree name
-
-    Returns
-    -------
-    list(str)
-       list of branches
-
-    Examples
-    --------
-
-    Grab branches for a file that are relevant for applying BDT models
-    and do something useful
-
-    >>> from tdub.utils import conservative_branches
-    >>> from tdub.frames import raw_dataframe
-    >>> from tdub.apply import FoldedResult, to_dataframe
-    >>> cb = conservative_branches("/path/to/file.root")
-    >>> df = raw_dataframe("/path/to/file.root", branches=cb)
-    >>> fr_2j2b = FoldedResult("/path/to/trained/fold2j2b", "2j2b")
-    >>> fr_2j1b = FoldedResult("/path/to/trained/fold2j1b", "2j1b")
-    >>> fr_2j2b.to_dataframe(df, query=True)
-    >>> fr_2j1b.to_dataframe(df, query=True)
-
-    """
-    branches_in_file = get_branches(file_name)
-    good_branches = set(
-        {"reg1j1b", "reg2j1b", "reg2j2b", "OS"}
-        | set(tdub.constants.FEATURESET_1j1b)
-        | set(tdub.constants.FEATURESET_2j1b)
-        | set(tdub.constants.FEATURESET_2j2b)
-    )
-    good_branches = set(branches_in_file) & good_branches
-    return sorted(good_branches, key=str.lower)
-
-
 def get_selection(region: Union[str, Region]) -> str:
     """Get the selection given a region
 
@@ -620,7 +527,6 @@ def get_selection(region: Union[str, Region]) -> str:
 
     Examples
     --------
-
     >>> from tdub.utils import get_selection, Region
     >>> get_selection(Region.r2j1b)
     '(reg2j1b == True) & (OS == True)'
@@ -659,7 +565,6 @@ def get_avoids(region: Union[str, Region]) -> List[str]:
 
     Examples
     --------
-
     >>> from tdub.utils import get_avoids, Region
     >>> get_avoids(Region.r2j1b)
     ['HT_jet1jet2', 'deltaR_lep1lep2_jet1jet2met', 'mass_lep2jet1', 'pT_jet2']
@@ -697,7 +602,6 @@ def get_features(region: Union[str, Region]) -> List[str]:
 
     Examples
     --------
-
     >>> from pprint import pprint
     >>> from tdub.utils import get_features
     >>> pprint(get_features("reg2j1b"))
@@ -747,7 +651,6 @@ def augment_features(region: Union[str, Region], to_add: List[str]) -> None:
 
     Examples
     --------
-
     >>> from tdub.utils import augment_features, get_features
     >>> "another" in get_features("2j2b")
     False
@@ -804,7 +707,6 @@ def override_features(table: Dict[str, List[str]]) -> None:
 
     Examples
     --------
-
     Using the dictionary above as an example
 
     >>> from tdub.utils import override_features, get_features
@@ -831,191 +733,6 @@ def override_features(table: Dict[str, List[str]]) -> None:
         tdub.constants.FEATURESET_2j2b = copy.deepcopy(table["r2j2b"])
 
 
-def kolmogorov_prob(z: float) -> float:
-    """Calculates the Kolmogorov distribution function
-
-    See ROOT's implementation in TMath_ (TMath::KolmogorovProb).
-
-    .. _TMath: https://root.cern.ch/doc/master/namespaceTMath.html
-
-    Parameters
-    ----------
-    z : float
-       the value to test
-
-    Returns
-    -------
-    float
-       the probability that the test statistic exceeds :math:`z`
-       (assuming the null hypothesis).
-
-    Examples
-    --------
-
-    >>> from tdub.utils import kolmogorov_prob
-    >>> kolmogorov_prob(1.13)
-    0.15549781841748692
-
-    """
-    w = 2.50662827
-    # c1 - -pi**2/8, c2 = 9*c1, c3 = 25*c1
-    c1 = -1.2337005501361697
-    c2 = -11.103304951225528
-    c3 = -30.842513753404244
-    u = abs(z)
-    if u < 0.2:
-        return 1.0
-    elif u < 0.755:
-        v = 1.0 / (u * u)
-        return float(1 - w * (math.exp(c1 * v) + math.exp(c2 * v) + math.exp(c3 * v)) / u)
-    elif u < 6.8116:
-        fj = np.array([-2, -8, -18, -32], dtype=np.float64)
-        r = np.zeros((4,), dtype=np.float64)
-        v = u * u
-        maxj = max(1.0, round(3.0 / u))
-        for j in range(int(maxj)):
-            r[j] = math.exp(fj[j] * v)
-        return float(2 * (r[0] - r[1] + r[2] - r[3]))
-    else:
-        return float(0.0)
-
-
-def ks_twosample_binned(
-    hist1: np.ndarray, hist2: np.ndarray, err1: np.ndarray, err2: np.ndarray
-) -> Tuple[float, float]:
-    """Calculate KS statistic and p-value for two binned distributions
-
-    See ROOT's implementation in TH1_ (TH1::KolmogorovTest).
-
-    .. _TH1: https://root.cern.ch/doc/master/classTH1.html
-
-    Parameters
-    ----------
-    hist1 : numpy.ndarray
-       the histogram counts for the first distribution
-    hist2 : numpy.ndarray
-       the histogram counts for the second distribution
-    err1 : numpy.ndarray
-       the error on the histogram counts for the first distribution
-    err2 : numpy.ndarray
-       the error on the histogram counts for the second distribution
-
-    Returns
-    -------
-    (float, float)
-       first: the test-statistic; second: the probability of the test
-       (much less than 1 means distributions are incompatible)
-
-    Examples
-    --------
-
-    >>> import pygram11
-    >>> from tdub.utils import ks_twosample_binned
-    >>> data1, data2, w1, w2 = some_function_to_get_data()
-    >>> h1, err1 = pygram11.histogram(data1, weights=w1, bins=40, range=(-3, 3))
-    >>> h2, err2 = pygram11.histogram(data2, weights=w2, bins=40, range=(-3, 3))
-    >>> kst, ksp = ks_twosample_binned(h1, h2, err1, err2)
-
-    """
-    sum1 = np.sum(hist1)
-    sum2 = np.sum(hist2)
-    w1 = np.sum(err1 * err1)
-    w2 = np.sum(err2 * err2)
-    esum1 = sum1 * sum1 / w1
-    esum2 = sum2 * sum2 / w2
-    s1 = 1 / sum1
-    s2 = 1 / sum2
-    rsum1 = s1 * hist1
-    rsum2 = s2 * hist2
-    dfmax = float(np.max(np.abs(rsum1 - rsum2)))
-    z = float(dfmax * math.sqrt(esum1 * esum2 / (esum1 + esum2)))
-    return dfmax, kolmogorov_prob(z)
-
-
-def chisquared_cdf_c(chi2: float, ndf: float) -> float:
-    r"""Calculate :math:`\chi^2` probability from the value and degrees of freedom
-
-    See ROOT's ``TMath::Prob`` & ``ROOT::Math::chisquared_cdf_c``. Quoting
-    the ROOT documentation:
-
-    Computation of the probability for a certain :math:`\chi^2` and
-    number of degrees of freedom (ndf). Calculations are based on the
-    incomplete gamma function :math:`P(a,x)`, where
-    :math:`a=\mathrm{ndf}/2` and :math:`x=\chi^2/2`.
-
-    :math:`P(a,x)` represents the probability that the observed
-    :math:`\chi^2` for a correct model should be less than the value
-    :math:`\chi^2`. The returned probability corresponds to
-    :math:`1-P(a,x)`, which denotes the probability that an observed
-    :math:`\chi^2` exceeds the value :math:`\chi^2` by chance, even
-    for a correct model.
-
-    Parameters
-    ----------
-    chi2 : float
-       the :math:`\chi^2` value
-    ndf : float
-       the degrees of freedom
-
-    Returns
-    -------
-    float
-       the :math:`\chi^2` probability
-
-    """
-    return scipy.special.gammaincc(0.5 * ndf, 0.5 * chi2)
-
-
-def chisquared_test(
-    h1: np.ndarray, err1: np.ndarray, h2: np.ndarray, err2: np.ndarray,
-) -> Tuple[float, float, float]:
-    r"""Perform :math:`\chi^2` test on two histograms
-
-    Parameters
-    ----------
-    h1 : :py:obj:`numpy.ndarray`
-       the first histogram bin contents
-    h2 : :py:obj:`numpy.ndarray`
-       the second histogram bin contents
-    err1 : :py:obj:`numpy.ndarray`
-       the first histogram bin errors
-    err2 : :py:obj:`numpy.ndarray`
-       the second histogram bin errors
-
-    Returns
-    -------
-    (float, int, float)
-       the :math:`\chi^2` test value, the degrees of freedom, and the probability
-    """
-    # remove 0 bin heights
-    badh1 = h1 * h1 == 0
-    badh2 = h2 * h2 == 0
-    good_bins = np.invert(np.logical_or(badh1, badh2))
-    histo1 = h1[good_bins]
-    histo2 = h2[good_bins]
-    error1 = err1[good_bins]
-    error2 = err2[good_bins]
-
-    # degrees of freedom
-    nbins = histo1.shape[0]
-    ndf = nbins - 1
-
-    # sums
-    sum1 = np.sum(histo1)
-    sum2 = np.sum(histo2)
-    sumw1 = np.sum(error1 * error1)
-    sumw2 = np.sum(error2 * error2)
-
-    # chi2 calculation
-    error1sq = error1 * error1
-    error2sq = error2 * error2
-    sigma = sum1 * sum2 * error2sq + sum2 * sum2 * error1sq
-    delta = sum2 * histo1 - sum1 * histo2
-    chi2 = np.sum(delta * delta / sigma)
-
-    return (chi2, ndf, chisquared_cdf_c(chi2, ndf))
-
-
 def extended_selection(region: Union[Region, str], extra: str) -> str:
     """Construct an extended selection string for a region
 
@@ -1033,7 +750,6 @@ def extended_selection(region: Union[Region, str], extra: str) -> str:
 
     Examples
     --------
-
     >>> from tdub.utils import extended_selection
     >>> extended_selection("2j2b", "met < 120")
     '((reg2j2b == True) & (OS == True)) & (met < 120)'
@@ -1058,7 +774,6 @@ def minimal_branches(selection: str) -> Set[str]:
 
     Examples
     --------
-
     >>> from tdub.utils import minimal_selection_branches
     >>> selection = "(reg1j1b == True) & (OS == True) & (mass_lep1lep2 > 100)"
     >>> minimal_branches(selection)
